@@ -1,7 +1,7 @@
 {
     'name': "Odoo Facto customizations",
-    'version': '12.0.0.0.2',
-    'depends': ['account_payment_partner'],
+    'version': '12.0.0.0.3',
+    'depends': ['account_payment_order'],
     'author': "Coopdevs Treball SCCL",
     'website': 'https://coopdevs.org',
     'category': "Cooperative management",
